==> apache-seatunnel-web-1.0.0-src.tar.gz: apache-seatunnel-web-1.0.0-src/seatunnel-server/seatunnel-app/src/main/java/org/apache/seatunnel/app/thirdparty/metrics/EngineMetricsExtractorFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seatunnel.app.thirdparty.metrics;

import org.apache.seatunnel.app.domain.response.engine.Engine;
import org.apache.seatunnel.app.thirdparty.engine.SeaTunnelEngineMetricsExtractor;
import org.apache.seatunnel.server.common.SeatunnelErrorEnum;
import org.apache.seatunnel.server.common.SeatunnelException;

import lombok.AllArgsConstructor;
import lombok.Data;

@Data
@AllArgsConstructor
public class EngineMetricsExtractorFactory {

    private final Engine engine;

    public IEngineMetricsExtractor getEngineMetricsExtractor() {
        if (engine.getName().equals("SeaTunnel")) {
            return SeaTunnelEngineMetricsExtractor.getInstance();
        }

        throw new SeatunnelException(
                SeatunnelErrorEnum.UNSUPPORTED_ENGINE, engine.getName(), engine.getVersion());
    }
}

==> apache-seatunnel-web-1.0.2-src.tar.gz: apache-seatunnel-web-1.0.2-src/seatunnel-server/seatunnel-app/src/main/java/org/apache/seatunnel/app/thirdparty/metrics/EngineMetricsExtractorFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seatunnel.app.thirdparty.metrics;

import org.apache.seatunnel.app.common.EngineType;
import org.apache.seatunnel.app.domain.response.engine.Engine;
import org.apache.seatunnel.app.thirdparty.engine.SeaTunnelEngineMetricsExtractor;
import org.apache.seatunnel.server.common.SeatunnelErrorEnum;
import org.apache.seatunnel.server.common.SeatunnelException;

import lombok.AllArgsConstructor;
import lombok.Data;

@Data
@AllArgsConstructor
public class EngineMetricsExtractorFactory {

    private final Engine engine;

    public IEngineMetricsExtractor getEngineMetricsExtractor() {
        if (engine.getName() == EngineType.SeaTunnel) {
            return SeaTunnelEngineMetricsExtractor.getInstance();
        }

        throw new SeatunnelException(
                SeatunnelErrorEnum.UNSUPPORTED_ENGINE, engine.getName(), engine.getVersion());
    }
}
